<?php
namespace Ak\Hydrator\Strategy;

use Laminas\Hydrator\HydratorInterface;
use Laminas\Hydrator\Strategy\StrategyInterface;

/**
 * Omogućava korištenje hidratora za hidriranje vrijednosti.
 *
 * @package Ak\Hydrator\Strategy
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/hydrator
 */
final class HydratorStrategy implements StrategyInterface
{
    /** @var HydratorInterface */
    private $hydrator;
    /** @var string */
    private $objectClass;

    /**
     * HydratorStrategy constructor.
     * @param HydratorInterface $hydrator
     * @param string $objectClass
     */
    public function __construct(HydratorInterface $hydrator, string $objectClass)
    {
        $this->hydrator = $hydrator;
        $this->objectClass = $objectClass;
    }

    /**
     * Pretvara datu vrijednost za ekstrakciju.
     *
     * @param mixed $value
     *
     * @return mixed
     */
    public function extract($value)
    {
        return $this->hydrator->extract($value);
    }

    /**
     * Pretvara datu vrijednost za hidraciju.
     *
     * @param mixed $value
     *
     * @return mixed
     */
    public function hydrate($value)
    {
        $objectClass = $this->objectClass;
        return $this->hydrator->hydrate($value, new $objectClass());
    }
}
